@@ -39,7 +39,7 @@ def makes(ivar2):
     print(f"[!] The process was completed. You can now remove the make() function from {__name__}.py")
 
 def run(osfolder=None):
-    if osfolder is not None:
+    if osfolder != None:
         print("[PYOS-MANAGER] Running OS with PyOS.core.modules.oracle")
         time.sleep(1)
         try:
